%manovra impulsiva di trasferimento da orbita di partenza circolare ad orbita target
%con n passaggi dagli apsidi, con variazione prima dell'afelio e poi
%del perielio


%dati iniziali
%afelio e perielio dell'orbita di partenza (Terra)
R_a0=1; %UA
R_p0=1; %UA
%afelio e perielio dell'orbita target
R_an=1.1; %UA
R_pn=1.05; %UA
%numero di passaggi
n=3;

%costante gravitazionale eliocentrica
mu=1.33e+11; %km^3/s^2

%conversione distanze UA in km
R_a0=R_a0*1.496e+8; %km
R_p0=R_p0*1.496e+8; %km
R_pn=R_pn*1.496e+8; %km
R_an=R_an*1.496e+8; %km

%variazione totale del perielio 
deltaR_ptot=R_pn-R_p0;
%variazione del perielio per ogni passaggio
deltaR_p=deltaR_ptot/n;
%variazione totale dell'afelio 
deltaR_atot=R_an-R_a0;
%variazione dell'afelio per ogni passaggio
deltaR_a=deltaR_atot/n;
%velocità iniziale (velocità circolare della Terra attorno al Sole)
V_0=sqrt(mu/R_p0);
%inizializzazione perielio e afelio ai valori iniziali
    R_pi=R_p0;
    R_ai=R_a0;
    %inizializzazione velocità al valore iniziale
    V_pi=V_0;
    %creo il vettore che contiene i valori di n
    N=[1:1:n]';
    %creo il vettore che conterrà i valori dei deltaV ai perieli
    deltaV_p=zeros(n,1);
    %creo il vettore che conterrà i valori dei deltaV agli afeli
    deltaV_a=zeros(n,1);
    
for i=1:n 
   %definisco perielio e afelio al passo successivo
    R_pj=R_pi+deltaR_p;
    R_aj=R_ai+deltaR_a;
    %calcolo la velocità richiesta per la manovra al perielio per cambiare
    %l'afelio
    V_pj=sqrt(2*mu*((1/R_pi)-(1/(R_pi+R_aj))));
    %calcolo il costo al perielio
    deltaV_pj=V_pj-V_pi;
    %piazzo il valore del deltaV nel vettore
    deltaV_p(i,1)=deltaV_pj;
    
    %calcolo la velocità che ho all'afelio a fine manovra
    V_ai=sqrt(2*mu*((1/R_aj)-(1/(R_pi+R_aj))));
    %calcolo la velocità richiesta per la manovra all'afelio per cambiare
    %il perielio
    V_aj=sqrt(2*mu*((1/R_aj)-(1/(R_aj+R_pj))));
    %calcolo il costo all'afelio
    deltaV_aj=V_aj-V_ai;
    %piazzo il valore del deltaV nel vettore
    deltaV_a(i,1)=deltaV_aj;
    
    %reinizializzo i valori di perielio e afelio
    R_pi=R_pj;
    R_ai=R_aj;
    %reinizializzo la velocità al perielio
    V_pi=sqrt(2*mu*((1/R_pi)-(1/(R_ai+R_pi))));
    
end
%creo una tabella che mostra i deltaV per ogni passaggio
    table(deltaV_p,deltaV_a,N)
    
    %calcolo il costo totale di missione
    deltaV_tot=sum([sum(abs(deltaV_a)),sum(abs(deltaV_p))])
    