%manovra impulsiva di trasferimento da orbita di partenza circolare ad orbita target
%con n passaggi dagli apsidi, con variazione prima del perielio e poi
%dell'afelio, e cambio di inclinazione determinato sulla base del minimo
%valore di costo

clc
clear all
%dati iniziali
%afelio, perielio e inclinazione dell'orbita di partenza (Terra)
R_a0=1; %UA
R_p0=1; %UA
i_0=0; %°

%afelio, perielio e inclinazione dell'orbita target
R_an=0.95; %UA
R_pn=0.9; %UA
i_n=5; %°
%numero di passaggi
n=3;

%costante gravitazionale eliocentrica
mu=1.33e+11; %km^3/s^2

%conversione distanze UA in km
R_a0=R_a0*1.496e+8; %km
R_p0=R_p0*1.496e+8; %km
R_pn=R_pn*1.496e+8; %km
R_an=R_an*1.496e+8; %km

%conversione angoli ° in radianti
i_0=i_0*(pi/180); %rad
i_n=i_n*(pi/180); %rad

%variazione totale del perielio 
deltaR_ptot=R_pn-R_p0;
%variazione del perielio per ogni passaggio
deltaR_p=deltaR_ptot/n;
%variazione totale dell'afelio 
deltaR_atot=R_an-R_a0;
%variazione dell'afelio per ogni passaggio
deltaR_a=deltaR_atot/n;
%variazione totale dell'inclinazione
deltai_tot=i_n-i_0;
%variazione dell'inclinazione per ogni giro
deltai=deltai_tot/n;

%velocità iniziale (velocità circolare della Terra attorno al Sole)
V_0=sqrt(mu/R_a0);
%inizializzazione perielio e afelio ai valori iniziali
    R_pi=R_p0;
    R_ai=R_a0;
    %inizializzazione velocità al valore iniziale
    V_ai=V_0;
    %creo il vettore che contiene i valori di n
    N=[1:1:n]';
    %creo il vettore che conterrà i valori dei deltaV agli afeli
    deltaV_a=zeros(n,1);
    %creo il vettore che conterrà i valori dei deltaV ai perieli
    deltaV_p=zeros(n,1);
    %creo il vettore che conterrà i valori del parametro di ripartizione x
    X=zeros(n,1)
    
for i=1:n 
   %definisco perielio e afelio al passo successivo
    R_pj=R_pi+deltaR_p;
    R_aj=R_ai+deltaR_a;
    
    %definisco il parametro di ripartizione del cambio d'inclinazione 
    %tra afelio e perielio come incognita
    syms x
    
    %variazione dell'inclinazione per ogni passaggio al perielio
    deltai_p=x*deltai;
    %variazione dell'inclinazione per ogni passaggio all'afelio
    deltai_a=(1-x)*deltai;

    %calcolo la velocità richiesta per la manovra all'afelio che cambia il
    %perielio
    V_aj=sqrt(2*mu*((1/R_ai)-(1/(R_ai+R_pj))));
    
    %definisco il costo all'afelio con incognita x
    deltaV_aj=sqrt((V_aj)^2+(V_ai)^2-2*V_ai*V_aj*cos(deltai_a));
    
    %calcolo la velocità che ho al perielio a fine manovra
    V_pi=sqrt(2*mu*((1/R_pj)-(1/(R_ai+R_pj))));
    %calcolo la velocità richiesta per la manovra al perielio che cambia
    %l'afelio
    V_pj=sqrt(2*mu*((1/R_pj)-(1/(R_aj+R_pj))));
    %calcolo il costo al perielio con incognita x
    deltaV_pj=sqrt((V_pj)^2+(V_pi)^2-2*V_pi*V_pj*cos(deltai_p));
    
    %definisco il costo dato dalla somma dei due
    deltaV=deltaV_aj+deltaV_pj;
    %derivo il costo in x
    der_deltaV=diff(deltaV,x);
    %calcolo il valore di x per cui ho minimo costo annullando la derivata
    x=solve(der_deltaV==0,x);
    
    %ricalcolo tutto in funzione di tale valore di x
    deltai_p=x*deltai;
    deltai_a=(1-x)*deltai;
    
    deltaV_pj=sqrt((V_pj)^2+(V_pi)^2-2*V_pi*V_pj*cos(deltai_p));
    deltaV_aj=sqrt((V_aj)^2+(V_ai)^2-2*V_ai*V_aj*cos(deltai_a));
    
    %piazzo il valore dei deltaV e di x nei vettori
    deltaV_a(i,1)=deltaV_aj;
    deltaV_p(i,1)=deltaV_pj;
    X(i,1)=x;
    
    %reinizializzo i valori di perielio e afelio
    R_pi=R_pj;
    R_ai=R_aj;
    %reinizializzo la velocità all'afelio
    V_ai=sqrt(2*mu*((1/R_ai)-(1/(R_ai+R_pi))));
    
end
%creo una tabella che mostra i deltaV per ogni passaggio
    table(deltaV_a,deltaV_p,X,N)
    
     %calcolo il costo totale di missione
    deltaV_tot=sum([sum(abs(deltaV_p)),sum(abs(deltaV_a))])