clear all
clc
%%innanzitutto imposto un formato di visualizzazione di cifre decimali
%%maggiore
format long
%importo i dati relativi ai parametri orbitali di Terra e degli asteroidi
A=readmatrix('fort72.txt');
A(:,12)=readmatrix('risultati_reali.txt');
%definisco quindi i dati relativi alla Terra
a_E=A(1,3); %UA
e_E=A(1,4);
i_E=A(1,5)*pi/180; %rad
Omega_E=A(1,6)*pi/180; %rad
omega_E=A(1,7)*pi/180; %rad

%definisco i dati iniziali
%spinta
T=1.74; %mN
%velocità caratteristica
c=31; %km/s
%numero di giri
n=3;
%coefficiente di correzione deltaV
coeff=0.64;


%conversione grandezze 
%distanza UA in km
a_E=a_E*1.495978707e+8; %km
%spinta mN in kg*km/s^2
T=T*10^(-6); %kg*km/s^2

%definisco ora delle grandezze utili ad adimensionare;
%massa spacecraft
m_sc0=20; %kg
%distanza Terra-Sole (media)
r_0=1.495978707e+8; %km
%costante gravitazionale eliocentrica
mu=1.32712440042e+11; %km^3/s^2
%velocità Terra attorno al Sole
V_0=sqrt(mu/r_0); %km/s
%velocità angolare Terra attorno al Sole
vel_ang=V_0/r_0; %rad/s
%accelerazione centrifuga Terra 
acc=V_0^2/r_0; %km/s^2

%adimensionalizzo la spinta su accelerazione Terra e massa spacecraft
T_adim=T/(acc*m_sc0); %adimensionale
%definisco la massa adimensionata, riferita allo spacecraft, e pertanto
%unitaria
m_adim=1; %adimensionale
%definisco infine la velocità angolare adimensionata, riferita alla Terra
vel_ang_adim=1;

%creo la tabella che conterrà tutti i risultati parziali per ogni asteroide
risultati_parziali_asteroidi=table(zeros(186,10));

%creo la tabella che conterrà tutti i risultati totali per ogni asteroide
risultati_totali_asteroidi=table(zeros(62,5));

%a questo punto imposto il ciclo for che effettuerà i calcoli per ogni
%asteroide
for j=2:63
    %definisco i dati relativi al target
    a_t=A(j,3); %UA
    e_t=A(j,4); 
    i_t=A(j,5)*pi/180; %rad
    Omega_t=A(j,6)*pi/180; %rad
    omega_t=A(j,7)*pi/180; %rad
    m_ref=A(j,12); %kg
    
    %conversione grandezze 
    %distanza UA in km
    a_t=a_t*1.495978707e+8; %km

    %calcolo deltaa, deltae e deltai totali
    delta_a_tot=a_t-a_E; %km
    delta_e_tot=e_t-e_E; 
    delta_i_tot=i_t-i_E; %rad
    %applico ora la correzione sul deltai totale, per ottenere il deltai
    %per effetto mediato
    
    %parto dal calcolo dei delta_v adimensionati (rispetto alla Terra) per 
    %singole variazioni di semiasse, eccentricità e inclinazione
    delta_V_a=0.5*delta_a_tot/a_E; %adimensionale
    delta_V_e=0.649*delta_e_tot; %adimensionale
    delta_V_i=(pi/2)*delta_i_tot; %adimensionale
    
    %il deltaV per variazioni simultanee viene stimato come la somma
    %vettoriale dei 3
    delta_V=sqrt((delta_V_a)^2+(delta_V_e)^2+(delta_V_i)^2); %adimensionale
    
    %calcolo ora la durata dell'arco di spinta, sempre adimensionale
    delta_t=delta_V/(T_adim/m_adim); %adimensionale
    
    %infine calcolo la lunghezza angolare dell'arco deltatheta, utile per
    %correggere il delta i, includendo anche il numero di archi (pari al
    %doppio del numero di giri); essa sarà adimensionale, ovvero in
    %radianti
    delta_theta=delta_t*vel_ang_adim/(2*n); %rad
    
    %a questo punto calcolo il fattore di correzione di deltai, dato da 4
    %diversi contributi
    
    k0=1;
    %k0=0.6;
    k1=1-cos(2*omega_t);
    k2=1.5*e_t;
    k3=(3+cos(delta_theta))/4;
    %k3=1;
   
    k=k0+k1*k2*k3;
    
    %correggo infine il deltai, otteneNdo il deltai equivalente
    deltai_eq=delta_i_tot*k; %rad
    
    %procedo ora con il calcolo della manovra perielio-afelio
    %definisco innanzitutto afelio e perielio della Terra e del target
    R_a0=a_E*(1+e_E); %km
    R_p0=a_E*(1-e_E); %km
    R_an=a_t*(1+e_t); %km
    R_pn=a_t*(1-e_t); %km
    
    %variazione totale del perielio 
    deltaR_ptot=R_pn-R_p0; %km
    %variazione del perielio per ogni passaggio
    deltaR_p=deltaR_ptot/n; %km
    %variazione totale dell'afelio 
    deltaR_atot=R_an-R_a0; %km
    %variazione dell'afelio per ogni passaggio
    deltaR_a=deltaR_atot/n; %km
    
    %scelgo il criterio di ripartizione proporzionale ai deltaR
    %parametro di ripartizione proporzionale
    x=abs(deltaR_a)/(abs(deltaR_a)+abs(deltaR_p));
    
    %variazione dell'inclinazione per ogni passaggio al perielio
    deltai_p=x*deltai_eq/n; %rad
    %variazione dell'inclinazione per ogni passaggio all'afelio
    deltai_a=(1-x)*deltai_eq/n; %rad
    
    if deltaR_a<0 
    
    %ricalcolo la velocità iniziale: non più V_0, ma calcolata considerando
    %di essere all'afelio dell'orbita di partenza, ovvero della Terra
    
    V_ai=sqrt(mu*((2/R_a0)-(1/a_E))); %km/s
    
    %inizializzazione perielio e afelio ai valori iniziali
    R_pi=R_p0;
    R_ai=R_a0;
    
    %inizializzo il valore della massa
    m_sc_ai=m_sc0;
    
    %creo il vettore che contiene i valori di n
    N=[1:1:n]';
    %creo il vettore che conterrà i valori dei deltaV agli afeli
    deltaV_a=zeros(n,1);
    %creo il vettore che conterrà i valori dei deltaV ai perieli
    deltaV_p=zeros(n,1);
    %creo il vettore che conterrà i valori dei consumi agli afeli
    m_prop_af=zeros(n,1);
    %creo il vettore che conterrà i valori dei consumi ai perieli
    m_prop_pe=zeros(n,1);
    %creo il vettore che conterrà i valori della massa agli afeli
    m_sc_af=zeros(n,1);
    %creo il vettore che conterrà i valori della massa ai perieli
    m_sc_pe=zeros(n,1);
    %creo il vettore che conterrà i valori delle durate degli archi agli
    %afeli
    durata_archi_a=zeros(n,1);
    %creo il vettore che conterrà i valori delle durate degli archi ai
    %perieli
    durata_archi_p=zeros(n,1);
    
    for i=1:n
        %definisco perielio e afelio al passo successivo
        R_pj=R_pi+deltaR_p; %km
        R_aj=R_ai+deltaR_a; %km
        %calcolo la velocità richiesta per la manovra all'afelio che cambia
        %il perielio
        V_aj=sqrt(2*mu*((1/R_ai)-(1/(R_ai+R_pj)))); %km/s
        %calcolo il costo all'afelio con il teorema di Carnot
        deltaV_aj=sqrt((V_aj)^2+(V_ai)^2-2*V_ai*V_aj*cos(deltai_a)); %km/s
        
        %calcolo la velocità angolare durante l'arco
        vel_ang_aj=V_aj/R_ai; %rad/s
        %calcolo la lunghezza angolare dell'arco
        dtheta_aj=(deltaV_aj/(T/m_sc_ai))*vel_ang_aj; %rad
        %correggo il deltaV
        deltaV_aj=deltaV_aj*(1+coeff*(dtheta_aj/(2*pi))); %km/s
        %piazzo il valore del deltaV nel vettore
        deltaV_a(i,1)=deltaV_aj;
        
        %calcolo il consumo di propellente con l'equazione di Ciolkowskij
        m_prop_a=m_sc_ai*(1-exp(-deltaV_aj/c)); %kg
        %piazzo il valore del consumo nel vettore
        m_prop_af(i,1)=m_prop_a;
        %ricalcolo la massa dello spacecraft
        m_sc_aj=m_sc_ai-m_prop_a; %kg
        %piazzo il valore della massa nel vettore
        m_sc_af(i,1)=m_sc_aj;
        %calcolo la durata dell'arco di spinta
        durata_arco_a=deltaV_aj/(T/m_sc_aj); %sec
        %piazzo il valore della durata nel vettore
        durata_archi_a(i,1)=durata_arco_a/(3600*24); %giorni
        
        
        %calcolo la velocità che ho al perielio a fine manovra
        V_pi=sqrt(2*mu*((1/R_pj)-(1/(R_ai+R_pj)))); %km
        %calcolo la velocità richiesta per la manovra al perielio che cambia
        %l'afelio
        V_pj=sqrt(2*mu*((1/R_pj)-(1/(R_aj+R_pj)))); %km
        %calcolo il costo al perielio
        deltaV_pj=sqrt((V_pj)^2+(V_pi)^2-2*V_pi*V_pj*cos(deltai_p)); %km/s
        
         
        %calcolo la velocità angolare durante l'arco
        vel_ang_pj=V_pj/R_pj; %rad/s
        %calcolo la lunghezza angolare dell'arco
        dtheta_pj=(deltaV_pj/(T/m_sc_aj))*vel_ang_pj; %rad
        %correggo il deltaV
        deltaV_pj=deltaV_pj*(1+coeff*(dtheta_pj/(2*pi))); %km/s
        
        %piazzo il valore del deltaV nel vettore
        deltaV_p(i,1)=deltaV_pj;
        %calcolo il consumo di propellente con l'equazione di Ciolkowskij
        m_prop_p=m_sc_aj*(1-exp(-deltaV_pj/c)); %kg
        %piazzo il valore del consumo nel vettore
        m_prop_pe(i,1)=m_prop_p;
        %ricalcolo la massa dello spacecraft
        m_sc_pj=m_sc_aj-m_prop_p; %kg
        %piazzo il valore della massa nel vettore
        m_sc_pe(i,1)=m_sc_pj;
        %calcolo la durata dell'arco di spinta
        durata_arco_p=deltaV_pj/(T/m_sc_pj); %sec
        %piazzo il valore della durata nel vettore
        durata_archi_p(i,1)=durata_arco_p/(3600*24); %giorni
        
        
        %reinizializzo i valori di perielio e afelio
        R_pi=R_pj;
        R_ai=R_aj;
        %reinizializzo la velocità all'afelio
        V_ai=sqrt(2*mu*((1/R_ai)-(1/(R_ai+R_pi)))); %km
        %reinizializzo il valore della massa dello spacecraft
        m_sc_ai=m_sc_pj;    
    end
    %calcolo il costo totale di missione
    deltaV_tot=sum([sum(abs(deltaV_p)),sum(abs(deltaV_a))]);
    %calcolo il consumo totale di propellente
    m_prop=sum([sum(abs(m_prop_af)),sum(abs(m_prop_pe))]);
    %calcolo l'errore assoluto
    err_ass=m_prop-m_ref;
    %definisco la massa finale, ovvero al netto del propellente
    m_finale=m_sc_pe(n);
    %calcolo la durata totale degli archi di spinta
    durata_archi=sum([sum(abs(durata_archi_a)),sum(abs(durata_archi_p))])/365; %anni
    %creo una tabella che mostra i risultati per ogni passaggio
    risultati_parziali=table(deltaV_a,deltaV_p,m_prop_af,m_prop_pe, m_sc_af,m_sc_pe,durata_archi_a, durata_archi_p,N);
    %creo una tabella che mostra i risultati totali
    risultati_totali=table(deltaV_tot, m_prop,m_finale,durata_archi);
    
   n_asteroide=[j j j]';
    
    %piazzo i risultati parziali nella tabella
    risultati_parziali_asteroide(3*j-2:3*j,1:10)=table(deltaV_a,deltaV_p,m_prop_af,m_prop_pe, m_sc_af,m_sc_pe,durata_archi_a, durata_archi_p,N,n_asteroide);
   
    numero_asteroide=j;
    
    %cambio nuovamente le unità di misura per la visualizzazione
    a_t=a_t/1.495978707e+8; %UA
    i_t=i_t*(180/pi); %°
    omega_t=omega_t*(180/pi); %°
    R_pn=R_pn/1.495978707e+8; %UA
    R_an=R_an/1.495978707e+8; %UA
    delta_theta=delta_theta*(180/pi); %°
    deltai_eq=deltai_eq*(180/pi); %°
    
    %piazzo i risultati totali nella tabella
  risultati_totali_asteroide(j,1:19)=table(numero_asteroide,a_t,e_t,i_t,omega_t,R_pn,R_an,delta_theta,k1,k2,k3,k,deltai_eq,deltaV_tot, m_prop,m_ref,err_ass,m_finale,durata_archi);
    
    elseif deltaR_a>0
        %ricalcolo la velocità iniziale: non più V_0, ma calcolata considerando
    %di essere al perielio dell'orbita di partenza, ovvero della Terra
    
    V_pi=sqrt(mu*((2/R_p0)-(1/a_E))); %km/s
    
    %inizializzazione perielio e afelio ai valori iniziali
    R_pi=R_p0;
    R_ai=R_a0;
    
    %inizializzo il valore della massa
    m_sc_pi=m_sc0;
    
    %creo il vettore che contiene i valori di n
    N=[1:1:n]';
    %creo il vettore che conterrà i valori dei deltaV ai perieli
    deltaV_p=zeros(n,1);
    %creo il vettore che conterrà i valori dei deltaV agli afeli
    deltaV_a=zeros(n,1);
    %creo il vettore che conterrà i valori dei consumi ai perieli
    m_prop_pe=zeros(n,1);
    %creo il vettore che conterrà i valori dei consumi agli afeli
    m_prop_af=zeros(n,1);
     %creo il vettore che conterrà i valori della massa ai perieli
    m_sc_pe=zeros(n,1);
    %creo il vettore che conterrà i valori della massa agli afeli
    m_sc_af=zeros(n,1);
    %creo il vettore che conterrà i valori delle durate degli archi ai
    %perieli
    durata_archi_p=zeros(n,1);
    %creo il vettore che conterrà i valori delle durate degli archi agli
    %afeli
    durata_archi_a=zeros(n,1);
       
    for i=1:n
        %definisco perielio e afelio al passo successivo
        R_pj=R_pi+deltaR_p; %km
        R_aj=R_ai+deltaR_a; %km
        %calcolo la velocità richiesta per la manovra al perielio che cambia
        %l'afelio
        V_pj=sqrt(2*mu*((1/R_pi)-(1/(R_pi+R_aj)))); %km/s
        %calcolo il costo al perielio con il teorema di Carnot
        deltaV_pj=sqrt((V_pj)^2+(V_pi)^2-2*V_pi*V_pj*cos(deltai_p)); %km/s
             
        %calcolo la velocità angolare durante l'arco
        vel_ang_pj=V_pj/R_pi; %rad/s
        %calcolo la lunghezza angolare dell'arco
        dtheta_pj=(deltaV_pj/(T/m_sc_pi))*vel_ang_pj; %rad
        %correggo il deltaV
        deltaV_pj=deltaV_pj*(1+coeff*(dtheta_pj/(2*pi))); %km/s
        
        %piazzo il valore del deltaV nel vettore
        deltaV_p(i,1)=deltaV_pj;
        
        %calcolo il consumo di propellente con l'equazione di Ciolkowskij
        m_prop_p=m_sc_pi*(1-exp(-deltaV_pj/c)); %kg
        %piazzo il valore del consumo nel vettore
        m_prop_pe(i,1)=m_prop_p;
        %ricalcolo la massa dello spacecraft
        m_sc_pj=m_sc_pi-m_prop_p; %kg
        %piazzo il valore della massa nel vettore
        m_sc_pe(i,1)=m_sc_pj;
        %calcolo la durata dell'arco di spinta
        durata_arco_p=deltaV_pj/(T/m_sc_pj); %sec
        %piazzo il valore della durata nel vettore
        durata_archi_p(i,1)=durata_arco_p/(3600*24); %giorni
        
        
        %calcolo la velocità che ho all'afelio a fine manovra
        V_ai=sqrt(2*mu*((1/R_aj)-(1/(R_pi+R_aj)))); %km
        %calcolo la velocità richiesta per la manovra all'afelio che cambia
        %il perielio
        V_aj=sqrt(2*mu*((1/R_aj)-(1/(R_aj+R_pj)))); %km
        %calcolo il costo all'afelio
        deltaV_aj=sqrt((V_aj)^2+(V_ai)^2-2*V_ai*V_aj*cos(deltai_a)); %km/s
         
        %calcolo la velocità angolare durante l'arco
        vel_ang_aj=V_aj/R_aj; %rad/s
        %calcolo la lunghezza angolare dell'arco
        dtheta_aj=(deltaV_aj/(T/m_sc_pj))*vel_ang_aj; %rad
        %correggo il deltaV
        deltaV_aj=deltaV_aj*(1+coeff*(dtheta_aj/(2*pi))); %km/s
        
        %piazzo il valore del deltaV nel vettore
        deltaV_a(i,1)=deltaV_aj;
        %calcolo il consumo di propellente con l'equazione di Ciolkowskij
        m_prop_a=m_sc_pj*(1-exp(-deltaV_aj/c)); %kg
        %piazzo il valore del consumo nel vettore
        m_prop_af(i,1)=m_prop_a;
        %ricalcolo la massa dello spacecraft
        m_sc_aj=m_sc_pj-m_prop_a; %kg
        %piazzo il valore della massa nel vettore
        m_sc_af(i,1)=m_sc_aj;
        %calcolo la durata dell'arco di spinta
        durata_arco_a=deltaV_aj/(T/m_sc_aj); %sec
        %piazzo il valore della durata nel vettore
        durata_archi_a(i,1)=durata_arco_a/(3600*24); %giorni
        
        
        %reinizializzo i valori di perielio e afelio
        R_pi=R_pj;
        R_ai=R_aj;
        %reinizializzo la velocità al perielio
        V_pi=sqrt(2*mu*((1/R_pi)-(1/(R_ai+R_pi)))); %km
        %reinizializzo il valore della massa dello spacecraft
        m_sc_pi=m_sc_aj;    
    end
    %calcolo il costo totale di missione
    deltaV_tot=sum([sum(abs(deltaV_p)),sum(abs(deltaV_a))]);
    %calcolo il consumo totale di propellente
    m_prop=sum([sum(abs(m_prop_af)),sum(abs(m_prop_pe))]);
    %calcolo l'errore assoluto
    err_ass=m_prop-m_ref;
    %definisco la massa finale, ovvero al netto del propellente
    m_finale=m_sc_af(n);
    %calcolo la durata totale degli archi di spinta
    durata_archi=sum([sum(abs(durata_archi_a)),sum(abs(durata_archi_p))])/365; %anni
    %creo una tabella che mostra i risultati per ogni passaggio
    risultati_parziali=table(deltaV_p,deltaV_a,m_prop_pe,m_prop_af,m_sc_pe,m_sc_af,durata_archi_p,durata_archi_a,N);
    %creo una tabella che mostra i risultati totali
    risultati_totali=table(deltaV_tot, m_prop,m_finale,durata_archi);
    
   n_asteroide=[j j j]';
    
    %piazzo i risultati parziali nella tabella
    risultati_parziali_asteroide(3*j-2:3*j,1:10)=table(deltaV_a,deltaV_p,m_prop_af,m_prop_pe, m_sc_af,m_sc_pe,durata_archi_a, durata_archi_p,N,n_asteroide);
   
    numero_asteroide=j;
    
    %cambio nuovamente le unità di misura per la visualizzazione
    a_t=a_t/1.495978707e+8; %UA
    i_t=i_t*(180/pi); %°
    omega_t=omega_t*(180/pi); %°
    R_pn=R_pn/1.495978707e+8; %UA
    R_an=R_an/1.495978707e+8; %UA
    delta_theta=delta_theta*(180/pi); %°
    deltai_eq=deltai_eq*(180/pi); %°
    
    %piazzo i risultati totali nella tabella
  risultati_totali_asteroide(j,1:19)=table(numero_asteroide,a_t,e_t,i_t,omega_t,R_pn,R_an,delta_theta,k1,k2,k3,k,deltai_eq,deltaV_tot, m_prop,m_ref,err_ass,m_finale,durata_archi);
    
  
   end
end
writetable(risultati_totali_asteroide, 'risultati_correzione_differenziata.txt');

